@@ -1,8 +1,11 @@
 import pandas as pd
 import numpy as np
+import seaborn as sns
 import matplotlib.pyplot as plt
 from .private_func import _get_report, _get_report_composite
-import seaborn as sns
+import warnings
+
+warnings.filterwarnings("ignore")
 
 
 def get_report(delta, ret):
@@ -72,7 +75,7 @@ def get_composite_report(delta, ret):
     return pd.concat([report_all, report_sub])
 
 
-def get_pnl_plot(delta, ret, return_plot=False):
+def get_pnl_plot(delta, ret, return_plot=False, alpha=False):
     """
     delta: pd.Series with DatatimeIndex
     ret: pd.Series with DatatimeIndex
@@ -105,13 +108,23 @@ def get_pnl_plot(delta, ret, return_plot=False):
     ax2 = plt.subplot2grid((3, 1), (2, 0))
 
     pnl = indicator * ret
+    ind_long = indicator[indicator > 0]
+    ind_short = indicator[indicator <= 0]
+    pnl_long = ind_long * ret.reindex(ind_long.index)
+    pnl_short = ind_short * ret.reindex(ind_short.index)
+
     day_ret = (ret * 100).groupby(by=ret.index.to_series().apply(lambda x: x.date())).sum()
     day_pnl = pnl.groupby(by=pnl.index.to_series().apply(lambda x: x.date())).sum()
+    day_pnl_long = pnl_long.groupby(by=pnl_long.index.to_series().apply(lambda x: x.date())).sum()
+    day_pnl_short = pnl_short.groupby(by=pnl_short.index.to_series().apply(lambda x: x.date())).sum()
     DD_ss = day_pnl.cumsum() - day_pnl.cumsum().expanding(0).max()
 
     day_pnl.cumsum().plot(ax=ax1, label='Strategy')
-    (day_pnl.cumsum() - day_ret.cumsum()).plot(ax=ax1, label='Alpha')
+    day_pnl_long.cumsum().plot(ax=ax1, label='Only Long', c='r', ls='--')
+    day_pnl_short.cumsum().plot(ax=ax1, label='Only Short', c='g', ls='--')
     day_ret.cumsum().plot(ax=ax1, ls=':', c='k', alpha=0.5, label='Asset')
+    if alpha:
+        (day_pnl.cumsum() - day_ret.cumsum()).plot(ax=ax1, label='Alpha', ls='--', alpha=0.4)
 
     ax1.set_title('PnL={} PoT={} Sharpe={} WR={:.2f} Worst={:.2f}'.format(
         report_all.loc['PnL'], report_all.loc['PoT'], report_all.loc['Sharpe'], report_all.loc['WR'],
@@ -137,7 +150,7 @@ def get_pnl_plot(delta, ret, return_plot=False):
     return
 
 
-def get_composite_pnl_plot(delta, ret, return_plot=False):
+def get_composite_pnl_plot(delta, ret, return_plot=False, alpha=False):
     """
     Multi-Assets PnL
     delta: pd.DataFrame with DatatimeIndex
@@ -161,8 +174,13 @@ def get_composite_pnl_plot(delta, ret, return_plot=False):
 
     inf_ind = np.isinf(indicator)
     indicator[inf_ind] = np.nan
-    indicator.dropna(inplace=True)
-    ret = ret.reindex(indicator.index)
+    indicator.fillna(0, inplace=True)
+
+    #
+    ind_long = indicator.copy()
+    ind_short = indicator.copy()
+    ind_long[ind_long < 0] = 0
+    ind_short[ind_short > 0] = 0
 
     indicator_og = pd.DataFrame(100.0 / len(indicator.columns), index=indicator.index, columns=indicator.columns)
 
@@ -174,13 +192,23 @@ def get_composite_pnl_plot(delta, ret, return_plot=False):
 
     #
     pnl = (indicator * ret).sum(axis=1)
+    pnl_long = (ind_long * ret).sum(axis=1)
+    pnl_short = (ind_short * ret).sum(axis=1)
+
+    #
     day_ret = (indicator_og * ret).sum(axis=1).groupby(by=ret.index.to_series().apply(lambda x: x.date())).sum()
     day_pnl = pnl.groupby(by=pnl.index.to_series().apply(lambda x: x.date())).sum()
+    day_pnl_long = pnl_long.groupby(by=pnl_long.index.to_series().apply(lambda x: x.date())).sum()
+    day_pnl_short = pnl_short.groupby(by=pnl_short.index.to_series().apply(lambda x: x.date())).sum()
     DD_ss = day_pnl.cumsum() - day_pnl.cumsum().expanding(0).max()
 
+    #
     day_pnl.cumsum().plot(ax=ax1, label='Strategy')
-    (day_pnl.cumsum() - day_ret.cumsum()).plot(ax=ax1, ls='--', label='Alpha')
+    day_pnl_long.cumsum().plot(ax=ax1, label='Only Long', c='r', ls='--')
+    day_pnl_short.cumsum().plot(ax=ax1, label='Only Short', c='g', ls='--')
     day_ret.cumsum().plot(ax=ax1, ls=':', c='k', alpha=0.5, label='Asset')
+    if alpha:
+        (day_pnl.cumsum() - day_ret.cumsum()).plot(ax=ax1, label='Alpha', ls='--', alpha=0.4)
 
     report_all = _get_report_composite(indicator, ret)
 
@@ -242,7 +270,7 @@ def round_test(delta, close, adj_close, BPV, mult=1e4, fee_rate=3e-4, vol_limit=
         return
 
     # vol without round
-    og_vol = ((delta*mult)/(BPV*close)).fillna(0)
+    og_vol = ((delta * mult) / (BPV * close)).fillna(0)
 
     # rounded vol
     vol = og_vol.round(0)
@@ -277,7 +305,7 @@ def round_test(delta, close, adj_close, BPV, mult=1e4, fee_rate=3e-4, vol_limit=
     new_pot = (new_pnl.sum().sum() / (new_vol.diff() * BPV * close).abs().sum().sum()) * 1e4
 
     def _sharpe(m):
-        return m.mean()/m.std() * 16.0
+        return m.mean() / m.std() * 16.0
 
     data_pnl = pd.concat([
         og_sum_pnl.rename('Orginal Delta: sharpe={:.2f} PoT={:.2f}'. \
@@ -287,7 +315,7 @@ def round_test(delta, close, adj_close, BPV, mult=1e4, fee_rate=3e-4, vol_limit=
         new_sum_pnl.rename('1 Volume Limit: sharpe={:.2f} PoT={:.2f}'. \
                            format(_sharpe(new_day_pnl), new_pot)),
         sum_pnl_ac.rename('Round Volume after-cost: sharpe={:.2f}'. \
-                          format(_sharpe(day_pnl_ac)))], axis=1)/mult
+                          format(_sharpe(day_pnl_ac)))], axis=1) / mult
 
     # plot
     plt.figure(figsize=(20, 16))
@@ -313,9 +341,3 @@ def round_test(delta, close, adj_close, BPV, mult=1e4, fee_rate=3e-4, vol_limit=
     plt.show()
 
     return
-
-
-
-
-
-
